@@ -213,19 +213,17 @@ class NavigationConfigForm extends ConfigForm
 
         $names = array();
         foreach ($this->getShareConfig($type) as $sectionName => $sectionConfig) {
-            if (
-                $sectionName !== $this->itemToLoad
+            if ((string) $sectionName !== $this->itemToLoad
                 && $sectionConfig->owner === ($owner ?: $this->getUser()->getUsername())
-                && !in_array($sectionName, $children, true)
+                && ! in_array($sectionName, $children, true)
             ) {
                 $names[] = $sectionName;
             }
         }
 
         foreach ($this->getUserConfig($type) as $sectionName => $sectionConfig) {
-            if (
-                $sectionName !== $this->itemToLoad
-                && !in_array($sectionName, $children, true)
+            if ((string) $sectionName !== $this->itemToLoad
+                && ! in_array($sectionName, $children, true)
             ) {
                 $names[] = $sectionName;
             }
@@ -301,7 +299,7 @@ class NavigationConfigForm extends ConfigForm
         $shared = false;
         $config = $this->getUserConfig($data['type']);
         if ((isset($data['users']) && $data['users']) || (isset($data['groups']) && $data['groups'])) {
-            if ($this->getUser()->can('application/share/navigation')) {
+            if ($this->getUser()->can('user/share/navigation')) {
                 $data['owner'] = $this->getUser()->getUsername();
                 $config = $this->getShareConfig($data['type']);
                 $shared = true;
@@ -365,14 +363,14 @@ class NavigationConfigForm extends ConfigForm
         $shared = false;
         if ($this->hasBeenShared($name)) {
             if (isset($data['parent']) && $data['parent']
-                ? !$this->hasBeenShared($data['parent'])
-                : ((! isset($data['users']) || !$data['users']) && (! isset($data['groups']) || !$data['groups']))
+                ? ! $this->hasBeenShared($data['parent'])
+                : ((! isset($data['users']) || ! $data['users']) && (! isset($data['groups']) || ! $data['groups']))
             ) {
                 // It is shared but shouldn't anymore
                 $config = $this->unshare($name, isset($data['parent']) ? $data['parent'] : null);
             }
         } elseif ((isset($data['users']) && $data['users']) || (isset($data['groups']) && $data['groups'])) {
-            if ($this->getUser()->can('application/share/navigation')) {
+            if ($this->getUser()->can('user/share/navigation')) {
                 // It is not shared yet but should be
                 $this->secondaryConfig = $config;
                 $config = $this->getShareConfig();
@@ -426,11 +424,6 @@ class NavigationConfigForm extends ConfigForm
         }
 
         $itemConfig->merge($data);
-        foreach ($itemConfig->toArray() as $k => $v) {
-            if ($v === null) {
-                unset($itemConfig->$k);
-            }
-        }
 
         if ($shared) {
             // Share all descendant children
@@ -567,7 +560,7 @@ class NavigationConfigForm extends ConfigForm
         $itemType = isset($formData['type']) ? $formData['type'] : key($itemTypes);
         if ($itemType === null) {
             throw new ProgrammingError(
-                'This should actually not happen. Create a bug report at dev.icinga.org'
+                'This should actually not happen. Create a bug report at https://github.com/icinga/icingaweb2'
                 . ' or remove this assertion if you know what you\'re doing'
             );
         }
@@ -586,9 +579,8 @@ class NavigationConfigForm extends ConfigForm
             )
         );
 
-        if (
-            (! $itemForm->requiresParentSelection() || !isset($formData['parent']) || !$formData['parent'])
-            && $this->getUser()->can('application/share/navigation')
+        if ((! $itemForm->requiresParentSelection() || ! isset($formData['parent']) || ! $formData['parent'])
+            && $this->getUser()->can('user/share/navigation')
         ) {
             $checked = isset($formData['shared']) ? null : (isset($formData['users']) || isset($formData['groups']));
 
@@ -607,7 +599,7 @@ class NavigationConfigForm extends ConfigForm
             if ($checked || (isset($formData['shared']) && $formData['shared'])) {
                 $shared = true;
                 $this->addElement(
-                    'text',
+                    'textarea',
                     'users',
                     array(
                         'label'         => $this->translate('Users'),
@@ -617,7 +609,7 @@ class NavigationConfigForm extends ConfigForm
                     )
                 );
                 $this->addElement(
-                    'text',
+                    'textarea',
                     'groups',
                     array(
                         'label'         => $this->translate('Groups'),
@@ -670,12 +662,12 @@ class NavigationConfigForm extends ConfigForm
                         'The parent item to assign this navigation item to. '
                         . 'Select "None" to make this a main navigation item'
                     ),
-                    'multiOptions'  => array_merge(
-                        array('' => $this->translate('None', 'No parent for a navigation item')),
-                        empty($availableParents) ? array() : array_combine($availableParents, $availableParents)
-                    )
+                    'multiOptions'  => ['' => $this->translate('None', 'No parent for a navigation item')]
+                        + (empty($availableParents) ? [] : array_combine($availableParents, $availableParents))
                 )
             );
+        } else {
+            $this->addElement('hidden', 'parent', ['disabled'  => true]);
         }
 
         $this->addSubForm($itemForm, 'item_form');
@@ -727,10 +719,12 @@ class NavigationConfigForm extends ConfigForm
                 if (! empty($forbiddenUsers)) {
                     $valid = false;
                     $this->getElement('users')->addError(
-                        $this->translate(sprintf(
-                            'You are not permitted to share this navigation item with the following users: %s',
+                        sprintf(
+                            $this->translate(
+                                'You are not permitted to share this navigation item with the following users: %s'
+                            ),
                             implode(', ', $forbiddenUsers)
-                        ))
+                        )
                     );
                 }
             }
@@ -749,10 +743,12 @@ class NavigationConfigForm extends ConfigForm
                 if (! empty($forbiddenGroups)) {
                     $valid = false;
                     $this->getElement('groups')->addError(
-                        $this->translate(sprintf(
-                            'You are not permitted to share this navigation item with the following groups: %s',
+                        sprintf(
+                            $this->translate(
+                                'You are not permitted to share this navigation item with the following groups: %s'
+                            ),
                             implode(', ', $forbiddenGroups)
-                        ))
+                        )
                     );
                 }
             }
@@ -786,9 +782,8 @@ class NavigationConfigForm extends ConfigForm
         if ($this->getUserConfig()->hasSection($name)) {
             return $this->getUserConfig();
         } elseif ($this->getShareConfig()->hasSection($name)) {
-            if (
-                $this->getShareConfig()->get($name, 'owner') === $this->getUser()->getUsername()
-                || $this->getUser()->can('config/application/navigation')
+            if ($this->getShareConfig()->get($name, 'owner') === $this->getUser()->getUsername()
+                || $this->getUser()->can('user/share/navigation')
             ) {
                 return $this->getShareConfig();
             }
