@@ -23,11 +23,11 @@ class Donut
     protected $labelBigUrl;
 
     /**
-     * Whether the big label shall be eye-catching
+     * The state the big label shall indicate
      *
-     * @var bool
+     * @var string|null
      */
-    protected $labelBigEyeCatching = true;
+    protected $labelBigState = 'critical';
 
     /**
      * Small label in the lower part of the donuts hole
@@ -194,7 +194,7 @@ class Donut
      */
     public function getLabelBigEyeCatching()
     {
-        return $this->labelBigEyeCatching;
+        return $this->labelBigState !== null;
     }
 
     /**
@@ -206,7 +206,31 @@ class Donut
      */
     public function setLabelBigEyeCatching($labelBigEyeCatching = true)
     {
-        $this->labelBigEyeCatching = $labelBigEyeCatching;
+        $this->labelBigState = $labelBigEyeCatching ? 'critical' : null;
+
+        return $this;
+    }
+
+    /**
+     * Get the state the big label shall indicate
+     *
+     * @return string|null
+     */
+    public function getLabelBigState()
+    {
+        return $this->labelBigState;
+    }
+
+    /**
+     * Set the state the big label shall indicate
+     *
+     * @param string|null $labelBigState
+     *
+     * @return $this
+     */
+    public function setLabelBigState($labelBigState)
+    {
+        $this->labelBigState = $labelBigState;
 
         return $this;
     }
@@ -268,6 +292,7 @@ class Donut
         $svg['content'][] = array(
             'tag'        => 'circle',
             'attributes' => array(
+                'aria-hidden' => true,
                 'cx'           => 20,
                 'cy'           => 20,
                 'r'            => sprintf('%F', $this->radius),
@@ -297,7 +322,9 @@ class Donut
                     'r'                 => sprintf('%F', $this->radius),
                     'fill'              => 'transparent',
                     'stroke-width'      => $this->getThickness(),
-                    'stroke-dasharray'  => sprintf('%F', $slice[0]) . ' ' . sprintf('%F', (99.9 - $slice[0])), // 99.9 prevents gaps (slight overlap)
+                    'stroke-dasharray'  => sprintf('%F', $slice[0])
+                        . ' '
+                        . sprintf('%F', (99.9 - $slice[0])), // 99.9 prevents gaps (slight overlap)
                     'stroke-dashoffset' => sprintf('%F', $offset)
                 )
             );
@@ -327,10 +354,11 @@ class Donut
                     array(
                         'tag' => 'a',
                         'attributes' => array(
+                            'aria-label' => $labelBig . ' ' . $labelSmall,
                             'href' => $this->getLabelBigUrl() ? $this->getLabelBigUrl()->getAbsoluteUrl() : null,
-                            'class' => $this->labelBigEyeCatching
-                                ? 'donut-label-big donut-label-big-eye-catching'
-                                : 'donut-label-big'
+                            'class' => $this->labelBigState === null
+                                ? 'donut-label-big'
+                                : 'donut-label-big state-' . $this->labelBigState
                         ),
                         'content' => $this->shortenLabel($labelBig)
                     );
@@ -366,7 +394,7 @@ class Donut
     protected function shortenLabel($label)
     {
         if (is_numeric($label) && strlen($label) > 3) {
-            return '~' . substr(round($label, -3), 0, 1) . 'k';
+            return round($label, -3)/1000 . 'k';
         }
 
         return $label;
