@@ -8,10 +8,12 @@ use Icinga\Application\Config;
 use Icinga\Application\Logger;
 use Icinga\Exception\IcingaException;
 use Icinga\Exception\NotReadableError;
-use Icinga\Util\Translator;
+use ipl\I18n\Translation;
 
 abstract class Command
 {
+    use Translation;
+
     protected $app;
     protected $docs;
 
@@ -55,12 +57,14 @@ abstract class Command
         $this->commandName  = $commandName;
         $this->actionName   = $actionName;
         $this->params       = $app->getParams();
-        $this->screen       = Screen::instance($app);
+        $this->screen       = Screen::instance();
         $this->trace        = $this->params->shift('trace', false);
         $this->isVerbose    = $this->params->shift('verbose', false);
         $this->isDebugging  = $this->params->shift('debug', false);
         $this->configs      = [];
 
+        $this->translationDomain = $moduleName ?: 'icinga';
+
         if ($this->loadEnabledModules) {
             try {
                 $app->getModuleManager()->loadEnabledModules();
@@ -134,21 +138,6 @@ abstract class Command
         return $this->trace;
     }
 
-    /**
-     * Translate a string
-     *
-     * Autoselects the module domain, if any, and falls back to the global one if no translation could be found.
-     *
-     * @param   string  $text   The string to translate
-     *
-     * @return  string          The translated string
-     */
-    public function translate($text)
-    {
-        $domain = $this->moduleName === null ? 'icinga' : $this->moduleName;
-        return Translator::translate($text, $domain);
-    }
-
     public function fail($msg)
     {
         throw new IcingaException('%s', $msg);
