@@ -56,6 +56,7 @@ class StyleSheet
         'css/vendor/normalize.css',
         'css/icinga/base.less',
         'css/icinga/badges.less',
+        'css/icinga/configmenu.less',
         'css/icinga/mixins.less',
         'css/icinga/grid.less',
         'css/icinga/nav.less',
@@ -89,6 +90,9 @@ class StyleSheet
      */
     protected $app;
 
+    /** @var string[] Pre-compiled CSS files */
+    protected $cssFiles = [];
+
     /**
      * Less compiler
      *
@@ -105,15 +109,12 @@ class StyleSheet
 
     /**
      * Create the StyleSheet
-     *
-     * @param bool $disableModes Disable replacing compiled Less colors with CSS var() function calls and don't inject
-     *                           light mode calls
      */
-    public function __construct($disableModes = false)
+    public function __construct()
     {
         $app = Icinga::app();
         $this->app = $app;
-        $this->lessCompiler = new LessCompiler($disableModes);
+        $this->lessCompiler = new LessCompiler();
         $this->pubPath = $app->getBaseDir('public');
         $this->collect();
     }
@@ -125,7 +126,11 @@ class StyleSheet
     {
         foreach ($this->app->getLibraries() as $library) {
             foreach ($library->getCssAssets() as $lessFile) {
-                $this->lessCompiler->addLessFile($lessFile);
+                if (substr($lessFile, -4) === '.css') {
+                    $this->cssFiles[] = $lessFile;
+                } else {
+                    $this->lessCompiler->addLessFile($lessFile);
+                }
             }
         }
 
@@ -188,6 +193,16 @@ class StyleSheet
         $this->lessCompiler->setThemeMode($this->pubPath . '/css/modes/'. $mode . '.less');
     }
 
+    /**
+     * Get all collected files
+     *
+     * @return string[]
+     */
+    protected function getFiles(): array
+    {
+        return array_merge($this->cssFiles, $this->lessCompiler->getLessFiles());
+    }
+
     /**
      * Get the stylesheet for PDF export
      *
@@ -215,7 +230,13 @@ class StyleSheet
         if ($minified) {
             $this->lessCompiler->compress();
         }
-        return $this->lessCompiler->render();
+
+        $css = '';
+        foreach ($this->cssFiles as $cssFile) {
+            $css .= file_get_contents($cssFile);
+        }
+
+        return $css . $this->lessCompiler->render();
     }
 
     /**
@@ -223,13 +244,11 @@ class StyleSheet
      *
      * Does not cache the stylesheet if the HTTP header Cache-Control or Pragma is set to no-cache.
      *
-     * @param bool $minified     Whether to compress the stylesheet
-     * @param bool $disableModes Disable replacing compiled Less colors with CSS var() function calls and don't inject
-     *                           light mode calls
+     * @param   bool    $minified   Whether to compress the stylesheet
      */
-    public static function send($minified = false, $disableModes = false)
+    public static function send($minified = false)
     {
-        $styleSheet = new self($disableModes);
+        $styleSheet = new self();
 
         $request = $styleSheet->app->getRequest();
         $response = $styleSheet->app->getResponse();
@@ -237,14 +256,15 @@ class StyleSheet
 
         $noCache = $request->getHeader('Cache-Control') === 'no-cache' || $request->getHeader('Pragma') === 'no-cache';
 
-        if (! $noCache && FileCache::etagMatchesFiles($styleSheet->lessCompiler->getLessFiles())) {
+        $collectedFiles = $styleSheet->getFiles();
+        if (! $noCache && FileCache::etagMatchesFiles($collectedFiles)) {
             $response
                 ->setHttpResponseCode(304)
                 ->sendHeaders();
             return;
         }
 
-        $etag = FileCache::etagForFiles($styleSheet->lessCompiler->getLessFiles());
+        $etag = FileCache::etagForFiles($collectedFiles);
 
         $response->setHeader('ETag', $etag, true)
             ->setHeader('Content-Type', 'text/css', true);
@@ -290,6 +310,19 @@ class StyleSheet
         $app = Icinga::app();
 
         if ($theme && $theme !== self::DEFAULT_THEME) {
+            if (Hook::has('ThemeLoader')) {
+                try {
+                    $path = Hook::first('ThemeLoader')->getThemeFile($theme);
+                } catch (Exception $e) {
+                    Logger::error('Failed to call ThemeLoader hook: %s', $e);
+                    $path = null;
+                }
+
+                if ($path !== null) {
+                    return $path;
+                }
+            }
+
             if (($pos = strpos($theme, '/')) !== false) {
                 $moduleName = substr($theme, 0, $pos);
                 $theme = substr($theme, $pos + 1);
