@@ -16,9 +16,8 @@ class Zend_View_Helper_PluginOutput extends Zend_View_Helper_Abstract
      * @var array
      */
     protected static $txtPatterns = array(
-        '~\\\n~',
         '~\\\t~',
-         '~\\\n\\\n~',
+        '~\\\n~',
         '~(\[|\()OK(\]|\))~',
         '~(\[|\()WARNING(\]|\))~',
         '~(\[|\()CRITICAL(\]|\))~',
@@ -34,7 +33,6 @@ class Zend_View_Helper_PluginOutput extends Zend_View_Helper_Abstract
      * @var array
      */
     protected static $txtReplacements = array(
-        "\n",
         "\t",
         "\n",
         '<span class="state-ok">$1OK$2</span>',
@@ -52,9 +50,8 @@ class Zend_View_Helper_PluginOutput extends Zend_View_Helper_Abstract
      * @var array
      */
     protected static $htmlPatterns = array(
-        '~\\\n~',
         '~\\\t~',
-        '~\\\n\\\n~',
+        '~\\\n~',
         '~<table~'
     );
 
@@ -64,7 +61,6 @@ class Zend_View_Helper_PluginOutput extends Zend_View_Helper_Abstract
      * @var array
      */
     protected static $htmlReplacements = array(
-        "\n",
         "\t",
         "\n",
         '<table style="font-size: 0.75em"'
@@ -92,16 +88,18 @@ class Zend_View_Helper_PluginOutput extends Zend_View_Helper_Abstract
         if (empty($output)) {
             return '';
         }
+
         if ($command !== null) {
             $output = $this->hookRenderer->render($command, $output, ! $raw);
         }
-        if (preg_match('~<[^>]*["/\'][^>]*>~', $output)) {
+
+        if (preg_match('~<\w+(?>\s\w+=[^>]*)?>~', $output)) {
             // HTML
-            $output = preg_replace(
+            $output = HtmlPurifier::process(preg_replace(
                 self::$htmlPatterns,
                 self::$htmlReplacements,
-                HtmlPurifier::process($output)
-            );
+                $output
+            ));
             $isHtml = true;
         } else {
             // Plaintext
@@ -113,6 +111,7 @@ class Zend_View_Helper_PluginOutput extends Zend_View_Helper_Abstract
             );
             $isHtml = false;
         }
+
         $output = trim($output);
         // Add zero-width space after commas which are not followed by a whitespace character
         // in oder to help browsers to break words in plugin output
@@ -125,6 +124,7 @@ class Zend_View_Helper_PluginOutput extends Zend_View_Helper_Abstract
                 $output = '<div class="plugin-output preformatted">' . $output . '</div>';
             }
         }
+
         return $output;
     }
 
