@@ -3,6 +3,9 @@
 
 namespace Icinga\Module\Monitoring\Backend\Ido\Query;
 
+use Icinga\Data\Filter\Filter;
+use Icinga\Data\Filter\FilterExpression;
+
 /**
  * Query for host downtime start history records
  */
@@ -68,18 +71,16 @@ class HostdowntimestarthistoryQuery extends IdoQuery
         )
     );
 
-    /**
-     * {@inheritdoc}
-     */
-    public function whereToSql($col, $sign, $expression)
+    protected function requireFilterColumns(Filter $filter)
     {
-        if ($col === 'UNIX_TIMESTAMP(hdh.actual_start_time)') {
-            return 'hdh.actual_start_time ' . $sign . ' ' . $this->timestampForSql(
-                $this->valueToTimestamp($expression)
-            );
-        } else {
-            return parent::whereToSql($col, $sign, $expression);
+        if ($filter instanceof FilterExpression && $filter->getColumn() === 'timestamp') {
+            $this->requireColumn('timestamp');
+            $filter->setColumn('hdh.actual_start_time');
+            $filter->setExpression($this->timestampForSql($this->valueToTimestamp($filter->getExpression())));
+            return null;
         }
+
+        return parent::requireFilterColumns($filter);
     }
 
     /**
@@ -96,7 +97,7 @@ class HostdowntimestarthistoryQuery extends IdoQuery
             array()
         );
 
-        if (@func_get_arg(0) === false) {
+        if (func_num_args() === 0 || func_get_arg(0) === false) {
             $this->select->where(
                 "hdh.actual_start_time > '1970-01-02 00:00:00'"
             );
