@@ -349,7 +349,7 @@ class ServicestatusQuery extends IdoQuery
             []
         )->joinLeft(
             ['scgo' => 'icinga_objects'],
-            'scgo.object_id = scg.contactgroup_object_id AND scgo.is_active = 1 AND scgo.objecttype_id = 10',
+            'scgo.object_id = scg.contactgroup_object_id AND scgo.is_active = 1 AND scgo.objecttype_id = 11',
             []
         );
     }
@@ -494,6 +494,14 @@ class ServicestatusQuery extends IdoQuery
                 $groupedColumns[] = 'ss.servicestatus_id';
                 $groupedTables['servicestatus'] = true;
             }
+        } elseif ($table === 'contacts') {
+            $groupedColumns[] = 'sc.service_contact_id';
+            $groupedColumns[] = 'sco.object_id';
+            $groupedTables[$table] = true;
+        } elseif ($table === 'contactgroups') {
+            $groupedColumns[] = 'scg.service_contactgroup_id';
+            $groupedColumns[] = 'scgo.object_id';
+            $groupedTables[$table] = true;
         } else {
             parent::registerGroupColumns($alias, $table, $groupedColumns, $groupedTables);
         }
